@@ -48,6 +48,10 @@ class Exponential(DPMechanism):
     utility : list
         A list of non-negative utility values for each candidate.
 
+    monotonic : bool, default: False
+        Specifies if the utility function is monotonic, i.e. that adding an individual to the underlying dataset can
+        only increase the values in `utility`.
+
     candidates : list, optional
         An optional list of candidate labels.  If omitted, the zero-indexed list [0, 1, ..., n] is used.
 
@@ -55,12 +59,14 @@ class Exponential(DPMechanism):
         An optional list of measures for each candidate.  If omitted, a uniform measure is used.
 
     """
-    def __init__(self, *, epsilon, sensitivity, utility, candidates=None, measure=None):
+    def __init__(self, *, epsilon, sensitivity, utility, monotonic=False, candidates=None, measure=None):
         super().__init__(epsilon=epsilon, delta=0.0)
         self.sensitivity = self._check_sensitivity(sensitivity)
         self.utility, self.candidates, self.measure = self._check_utility_candidates_measure(utility, candidates,
                                                                                              measure)
-        self._probabilities = self._find_probabilities(self.epsilon, self.sensitivity, self.utility, self.measure)
+        self.monotonic = bool(monotonic)
+        self._probabilities = self._find_probabilities(self.epsilon, self.sensitivity, self.utility, self.monotonic,
+                                                       self.measure)
 
     @classmethod
     def _check_epsilon_delta(cls, epsilon, delta):
@@ -82,7 +88,7 @@ class Exponential(DPMechanism):
     @classmethod
     def _check_utility_candidates_measure(cls, utility, candidates, measure):
         if not isinstance(utility, list):
-            raise TypeError("Utility must be a list, got a {}.".format(utility))
+            raise TypeError(f"Utility must be a list, got a {utility}.")
 
         if not all(isinstance(u, Real) for u in utility):
             raise TypeError("Utility must be a list of real-valued numbers.")
@@ -95,14 +101,14 @@ class Exponential(DPMechanism):
 
         if candidates is not None:
             if not isinstance(candidates, list):
-                raise TypeError("Candidates must be a list, got a {}.".format(type(candidates)))
+                raise TypeError(f"Candidates must be a list, got a {type(candidates)}.")
 
             if len(candidates) != len(utility):
                 raise ValueError("List of candidates must be the same length as the list of utility values.")
 
         if measure is not None:
             if not isinstance(measure, list):
-                raise TypeError("Measure must be a list, got a {}.".format(type(measure)))
+                raise TypeError(f"Measure must be a list, got a {type(measure)}.")
 
             if not all(isinstance(m, Real) for m in measure):
                 raise TypeError("Measure must be a list of real-valued numbers.")
@@ -116,8 +122,8 @@ class Exponential(DPMechanism):
         return utility, candidates, measure
 
     @classmethod
-    def _find_probabilities(cls, epsilon, sensitivity, utility, measure):
-        scale = epsilon / sensitivity if sensitivity / epsilon > 0 else float("inf")
+    def _find_probabilities(cls, epsilon, sensitivity, utility, monotonic, measure):
+        scale = epsilon / sensitivity / (2 - monotonic) if sensitivity / epsilon > 0 else float("inf")
 
         # Set max utility to 0 to avoid overflow on high utility; will be normalised out before returning
         utility = np.array(utility) - max(utility)
@@ -125,7 +131,7 @@ class Exponential(DPMechanism):
         if np.isinf(scale):
             probabilities = np.isclose(utility, 0).astype(float)
         else:
-            probabilities = np.exp(scale * utility / 2)
+            probabilities = np.exp(scale * utility)
 
         probabilities *= np.array(measure) if measure else 1
         probabilities /= probabilities.sum()
@@ -138,7 +144,7 @@ class Exponential(DPMechanism):
         self._check_utility_candidates_measure(self.utility, self.candidates, self.measure)
 
         if value is not None:
-            raise ValueError("Value to be randomised must be None. Got: {}.".format(value))
+            raise ValueError(f"Value to be randomised must be None. Got: {value}.")
 
         return True
 
@@ -171,10 +177,10 @@ class Exponential(DPMechanism):
         if np.any(rand <= self._probabilities):
             idx = np.argmax(rand <= self._probabilities)
         elif np.isclose(rand, self._probabilities[-1]):
-            idx = len(self._probabilities)
+            idx = len(self._probabilities) - 1
         else:
             raise RuntimeError("Can't find a candidate to return. "
-                               "Debugging info: Rand: {}, Probabilities: {}".format(rand, self._probabilities))
+                               f"Debugging info: Rand: {rand}, Probabilities: {self._probabilities}")
 
         return self.candidates[idx] if self.candidates else idx
 
@@ -201,12 +207,17 @@ class PermuteAndFlip(Exponential):
     utility : list
         A list of non-negative utility values for each candidate.
 
+    monotonic : bool, default: False
+        Specifies if the utility function is monotonic, i.e. that adding an individual to the underlying dataset can
+        only increase the values in `utility`.
+
     candidates : list, optional
         An optional list of candidate labels.  If omitted, the zero-indexed list [0, 1, ..., n] is used.
 
     """
-    def __init__(self, *, epsilon, sensitivity, utility, candidates=None):
-        super().__init__(epsilon=epsilon, sensitivity=sensitivity, utility=utility, candidates=candidates, measure=None)
+    def __init__(self, *, epsilon, sensitivity, utility, monotonic=False, candidates=None):
+        super().__init__(epsilon=epsilon, sensitivity=sensitivity, utility=utility, monotonic=monotonic,
+                         candidates=candidates, measure=None)
 
     @copy_docstring(DPMechanism.bias)
     def bias(self, value):
@@ -217,8 +228,8 @@ class PermuteAndFlip(Exponential):
         raise NotImplementedError
 
     @classmethod
-    def _find_probabilities(cls, epsilon, sensitivity, utility, measure):
-        scale = epsilon / sensitivity if sensitivity / epsilon > 0 else float("inf")
+    def _find_probabilities(cls, epsilon, sensitivity, utility, monotonic, measure):
+        scale = epsilon / sensitivity / (2 - monotonic) if sensitivity / epsilon > 0 else float("inf")
 
         utility = np.array(utility)
         utility -= max(utility)
@@ -227,7 +238,7 @@ class PermuteAndFlip(Exponential):
             log_probabilities = np.ones_like(utility) * (-float("inf"))
             log_probabilities[utility == 0] = 0
         else:
-            log_probabilities = scale * utility / 2
+            log_probabilities = scale * utility
 
         return log_probabilities
 
@@ -256,7 +267,7 @@ class PermuteAndFlip(Exponential):
             if bernoulli_neg_exp(-self._probabilities[idx], self._rng):
                 return self.candidates[idx] if self.candidates else idx
 
-        raise RuntimeError("No value to return.  Probabilities: {}.".format(self._probabilities))
+        raise RuntimeError(f"No value to return.  Probabilities: {self._probabilities}.")
 
 
 class ExponentialCategorical(DPMechanism):
@@ -339,7 +350,7 @@ class ExponentialCategorical(DPMechanism):
                     missing.append((val1, val2))
 
         if missing:
-            raise ValueError("Utility values missing: %s" % (str(missing)))
+            raise ValueError(f"Utility values missing: {missing}")
 
         return True
 
@@ -410,7 +421,7 @@ class ExponentialCategorical(DPMechanism):
             raise TypeError("Value to be randomised must be a string")
 
         if value not in self._domain_values:
-            raise ValueError("Value \"%s\" not in domain" % value)
+            raise ValueError(f"Value \"{value}\" not in domain")
 
         return True
 
@@ -503,9 +514,10 @@ class ExponentialHierarchical(ExponentialCategorical):
             if hierarchy_height is None:
                 hierarchy_height = len(_hierarchy_locator)
             elif len(_hierarchy_locator) != hierarchy_height:
-                raise ValueError("Leaves of the hierarchy must all be at the same level " +
-                                 "(node %s is at level %d instead of hierarchy height %d)" %
-                                 (_hierarchy_locator.__str__(), len(_hierarchy_locator), hierarchy_height))
+                raise ValueError(
+                    f"Leaves of the hierarchy must all be at the same level (node {_hierarchy_locator.__str__()} is at "
+                    f"level {len(_hierarchy_locator)} instead of hierarchy height {hierarchy_height})"
+                )
 
     @staticmethod
     def _build_utility_list(hierarchy):
