@@ -48,14 +48,14 @@ import warnings
 import numpy as np
 import sklearn.linear_model as sk_lr
 from scipy.optimize import minimize
-from sklearn.utils import check_X_y, check_array
+from sklearn.utils import check_array
 from sklearn.utils.validation import FLOAT_DTYPES
 
 from diffprivlib.accountant import BudgetAccountant
 from diffprivlib.mechanisms import Laplace, LaplaceFolded
 from diffprivlib.tools import mean
 from diffprivlib.utils import warn_unused_args, PrivacyLeakWarning
-from diffprivlib.validation import check_bounds, clip_to_bounds
+from diffprivlib.validation import check_bounds, clip_to_bounds, DiffprivlibMixin
 
 
 # noinspection PyPep8Naming
@@ -112,7 +112,7 @@ def _construct_regression_obj(X, y, bounds_X, bounds_y, epsilon, alpha):
     mono_coef_0 = np.zeros(n_targets)
 
     for i in range(n_targets):
-        sensitivity = np.abs(bounds_y[i]).max() ** 2
+        sensitivity = np.abs([bounds_y[0][i], bounds_y[1][i]]).max() ** 2
         mech = LaplaceFolded(epsilon=local_epsilon, sensitivity=sensitivity, lower=0, upper=float("inf"))
         mono_coef_0[i] = mech.randomise(coefs[0][i])
 
@@ -142,26 +142,26 @@ def _construct_regression_obj(X, y, bounds_X, bounds_y, epsilon, alpha):
     del coefs
     noisy_coefs = (mono_coef_0, mono_coef_1, mono_coef_2)
 
-    output = []
-
-    for i in range(n_targets):
-        def obj(omega):
-            func = noisy_coefs[0][i]
-            func -= 2 * np.dot(noisy_coefs[1][:, i], omega)
+    def obj(idx):
+        def inner_obj(omega):
+            func = noisy_coefs[0][idx]
+            func -= 2 * np.dot(noisy_coefs[1][:, idx], omega)
             func += np.multiply(noisy_coefs[2], np.tensordot(omega, omega, axes=0)).sum()
             func += alpha * (omega ** 2).sum()
 
-            grad = - 2 * noisy_coefs[1][:, i] + 2 * np.matmul(noisy_coefs[2], omega) + 2 * omega * alpha
+            grad = - 2 * noisy_coefs[1][:, idx] + 2 * np.matmul(noisy_coefs[2], omega) + 2 * omega * alpha
 
             return func, grad
 
-        output += [obj]
+        return inner_obj
 
-    return tuple(output), noisy_coefs
+    output = tuple(obj(i) for i in range(n_targets))
+
+    return output, noisy_coefs
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit
-class LinearRegression(sk_lr.LinearRegression):
+class LinearRegression(sk_lr.LinearRegression, DiffprivlibMixin):
     r"""
     Ordinary least squares Linear Regression with differential privacy.
 
@@ -211,17 +211,16 @@ class LinearRegression(sk_lr.LinearRegression):
         regression analysis under differential privacy." arXiv preprint arXiv:1208.0219 (2012).
 
     """
-    def __init__(self, epsilon=1.0, bounds_X=None, bounds_y=None, fit_intercept=True, copy_X=True, accountant=None,
+    def __init__(self, *, epsilon=1.0, bounds_X=None, bounds_y=None, fit_intercept=True, copy_X=True, accountant=None,
                  **unused_args):
-        super().__init__(fit_intercept=fit_intercept, normalize=False, copy_X=copy_X, n_jobs=None)
+        super().__init__(fit_intercept=fit_intercept, copy_X=copy_X, n_jobs=None)
 
         self.epsilon = epsilon
         self.bounds_X = bounds_X
         self.bounds_y = bounds_y
         self.accountant = BudgetAccountant.load_default(accountant)
-        self.__repr__()
 
-        warn_unused_args(unused_args)
+        self._warn_unused_args(unused_args)
 
     def fit(self, X, y, sample_weight=None):
         """
@@ -241,13 +240,14 @@ class LinearRegression(sk_lr.LinearRegression):
         Returns
         -------
         self : returns an instance of self.
+
         """
         self.accountant.check(self.epsilon, 0)
 
         if sample_weight is not None:
-            warn_unused_args("sample_weight")
+            self._warn_unused_args("sample_weight")
 
-        X, y = check_X_y(X, y, accept_sparse=False, y_numeric=True, multi_output=True)
+        X, y = self._validate_data(X, y, accept_sparse=False, y_numeric=True, multi_output=True)
 
         if self.bounds_X is None or self.bounds_y is None:
             warnings.warn(
@@ -262,8 +262,8 @@ class LinearRegression(sk_lr.LinearRegression):
             if self.bounds_y is None:
                 self.bounds_y = (np.min(y, axis=0), np.max(y, axis=0))
 
-        self.bounds_X = check_bounds(self.bounds_X, X.shape[1])
-        self.bounds_y = check_bounds(self.bounds_y, y.shape[1] if y.ndim > 1 else 1)
+        self.bounds_X = self._check_bounds(self.bounds_X, X.shape[1])
+        self.bounds_y = self._check_bounds(self.bounds_y, y.shape[1] if y.ndim > 1 else 1)
 
         n_features = X.shape[1]
         n_targets = y.shape[1] if y.ndim > 1 else 1
