@@ -48,15 +48,11 @@ import warnings
 import numpy as np
 import sklearn.preprocessing as sk_pp
 from sklearn.preprocessing._data import _handle_zeros_in_scale
-from sklearn.utils import check_array
-from sklearn.utils.validation import FLOAT_DTYPES
 
 from diffprivlib.accountant import BudgetAccountant
-from diffprivlib.utils import PrivacyLeakWarning, warn_unused_args
+from diffprivlib.utils import PrivacyLeakWarning
 from diffprivlib.tools import nanvar, nanmean
-from diffprivlib.validation import clip_to_bounds, check_bounds
-
-range_ = range
+from diffprivlib.validation import DiffprivlibMixin
 
 
 def _incremental_mean_and_var(X, epsilon, bounds, last_mean, last_variance, last_sample_count):
@@ -97,7 +93,7 @@ def _incremental_mean_and_var(X, epsilon, bounds, last_mean, last_variance, last
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit
-class StandardScaler(sk_pp.StandardScaler):
+class StandardScaler(sk_pp.StandardScaler, DiffprivlibMixin):
     """Standardize features by removing the mean and scaling to unit variance, calculated with differential privacy
     guarantees.  Differential privacy is guaranteed on the learned scaler with respect to the training sample; the
     transformed output will certainly not satisfy differential privacy.
@@ -171,7 +167,7 @@ class StandardScaler(sk_pp.StandardScaler):
     NaNs are treated as missing values: disregarded in fit, and maintained in transform.
 
     """  # noqa
-    def __init__(self, epsilon=1.0, bounds=None, copy=True, with_mean=True, with_std=True, accountant=None):
+    def __init__(self, *, epsilon=1.0, bounds=None, copy=True, with_mean=True, with_std=True, accountant=None):
         super().__init__(copy=copy, with_mean=with_mean, with_std=with_std)
         self.epsilon = epsilon
         self.bounds = bounds
@@ -201,24 +197,22 @@ class StandardScaler(sk_pp.StandardScaler):
         self.accountant.check(self.epsilon, 0)
 
         if sample_weight is not None:
-            warn_unused_args("sample_weight")
+            self._warn_unused_args("sample_weight")
 
         epsilon_0 = self.epsilon / 2 if self.with_std else self.epsilon
 
-        X = check_array(X, accept_sparse=False, copy=self.copy, estimator=self, dtype=FLOAT_DTYPES,
-                        force_all_finite='allow-nan')
-        # Hotfix for sklearn v 0.23
-        self.n_features_in_ = X.shape[1]
+        X = self._validate_data(X, accept_sparse=False, copy=self.copy, estimator=self, dtype=float,
+                                force_all_finite='allow-nan')
 
         if self.bounds is None:
-            warnings.warn("Range parameter hasn't been specified, so falling back to determining range from the data.\n"
-                          "This will result in additional privacy leakage.  To ensure differential privacy with no "
-                          "additional privacy loss, specify `range` for each valued returned by np.mean().",
+            warnings.warn("Bounds parameter hasn't been specified, so falling back to determining bounds from the "
+                          "data.\n This will result in additional privacy leakage.  To ensure differential privacy "
+                          "with no additional privacy loss, specify `bounds` for each valued returned by np.mean().",
                           PrivacyLeakWarning)
             self.bounds = (np.min(X, axis=0), np.max(X, axis=0))
 
-        self.bounds = check_bounds(self.bounds, X.shape[1])
-        X = clip_to_bounds(X, self.bounds)
+        self.bounds = self._check_bounds(self.bounds, X.shape[1])
+        X = self._clip_to_bounds(X, self.bounds)
 
         # Even in the case of `with_mean=False`, we update the mean anyway. This is needed for the incremental
         # computation of the var See incr_mean_variance_axis and _incremental_mean_variance_axis
