@@ -98,11 +98,17 @@ class TestGaussianNB(TestCase):
         for clf in [clf_dp, clf_non_private]:
             clf.fit(x_train, y_train)
 
+        # Todo: remove try...except when sklearn v1.0 is required
+        try:
+            nonprivate_var = clf_non_private.var_
+        except AttributeError:
+            nonprivate_var = clf_non_private.sigma_
+
         theta_diff = (clf_dp.theta_ - clf_non_private.theta_) ** 2
         self.assertGreater(theta_diff.sum(), 0)
 
-        sigma_diff = (clf_dp.sigma_ - clf_non_private.sigma_) ** 2
-        self.assertGreater(sigma_diff.sum(), 0)
+        var_diff = (clf_dp.var_ - nonprivate_var) ** 2
+        self.assertGreater(var_diff.sum(), 0)
 
     @pytest.mark.filterwarnings('ignore: numpy.ufunc size changed')
     def test_with_iris(self):
@@ -163,7 +169,7 @@ class TestGaussianNB(TestCase):
         with self.assertRaises(ValueError):
             clf.fit(X, y)
 
-    def test_refit(self):
+    def test_bad_refit_shape(self):
         X = np.random.random((10, 2))
         y = np.random.randint(2, size=10)
 
@@ -175,3 +181,35 @@ class TestGaussianNB(TestCase):
 
         with self.assertRaises(ValueError):
             clf.partial_fit(X2, y)
+
+    def test_bad_refit_classes(self):
+        X = np.random.random((10, 2))
+        y = np.random.randint(2, size=10)
+
+        clf = GaussianNB(epsilon=1, bounds=([0, 0], [1, 1]))
+        clf.fit(X, y)
+
+        X2 = np.random.random((10, 2))
+        y2 = np.random.randint(3, size=10)
+
+        with self.assertRaises(ValueError):
+            clf.partial_fit(X2, y2)
+
+    def test_update_mean_variance(self):
+        X = np.random.random((10, 2))
+        y = np.random.randint(2, size=10)
+
+        clf = GaussianNB(epsilon=1, bounds=([0, 0], [1, 1]))
+        self.assertIsNotNone(clf._update_mean_variance(0, 0, 0, X, n_noisy=5))
+        self.assertIsNotNone(clf._update_mean_variance(0, 0, 0, X, n_noisy=0))
+        self.assertWarns(PrivacyLeakWarning, clf._update_mean_variance, 0, 0, 0, X)
+        self.assertWarns(DiffprivlibCompatibilityWarning, clf._update_mean_variance, 0, 0, 0, X, n_noisy=1,
+                         sample_weight=1)
+
+    def test_sigma(self):
+        X = np.random.random((10, 2))
+        y = np.random.randint(2, size=10)
+
+        clf = GaussianNB(epsilon=1, bounds=([0, 0], [1, 1]))
+        clf.fit(X, y)
+        self.assertIsInstance(clf.sigma_, np.ndarray)
