@@ -104,7 +104,7 @@ class TestLinearRegression(TestCase):
 
         predict1 = clf.predict(X_test)
 
-        clf2 = linear_model.LinearRegression(normalize=False)
+        clf2 = linear_model.LinearRegression()
         clf2.fit(X_train, y_train)
 
         predict2 = clf2.predict(X_test)
@@ -125,10 +125,22 @@ class TestLinearRegression(TestCase):
         self.assertIsNotNone(clf)
         self.assertAlmostEqual(clf.predict(np.array([0.5]).reshape(-1, 1))[0], 0.5, delta=.05)
 
+    def test_copy(self):
+        X = np.linspace(-1, 1, 1000)
+        y = X.copy()
+        X = X[:, np.newaxis]
+
+        clf = LinearRegression(epsilon=2, fit_intercept=False, bounds_X=(-1, 1), bounds_y=(-1, 1), copy_X=True)
+        clf.fit(X, y)
+
+        self.assertIsNotNone(clf)
+        self.assertIsNotNone(clf._preprocess_data(X, y, fit_intercept=True, bounds_X=(-1, 1), bounds_y=(-1, 1),
+                                                  check_input=False, copy=True))
+
     def test_multiple_targets(self):
         from sklearn.linear_model import LinearRegression as sk_LinearRegression
         X = np.linspace(-1, 1, 1000)
-        y = np.vstack((X.copy(), X.copy())).T
+        y = np.vstack((X.copy(), X.copy(), X.copy(), X.copy())).T
         X = X[:, np.newaxis]
 
         clf_dp = LinearRegression(epsilon=2, fit_intercept=False, bounds_X=(-1, 1), bounds_y=(-1, 1))
@@ -148,7 +160,7 @@ class TestLinearRegression(TestCase):
 
         clf_dp2 = LinearRegression(epsilon=2, fit_intercept=True, bounds_X=(-1, 1), bounds_y=(-1, 1)).fit(X, y)
         self.assertIsNotNone(clf_dp2)
-        self.assertEqual(clf_dp2.intercept_.shape, (2,))
+        self.assertEqual(clf_dp2.intercept_.shape, (4,))
         self.assertEqual(clf_dp2.coef_.shape, clf_sk.coef_.shape)
         self.assertEqual(clf_dp2.predict(x0).shape, clf_sk.predict(x0).shape)
 
